/** @file Timing.h
    @brief Declaration of the Timing class

    This file is part of XLSX
    Output Office Open XML (OpenXML) spreadsheet files from native C++
    @author (C) Copyright 2013 Paolo Greppi libpf.com
    @date: 20130118
    @version: 0.1

    no warranties whatsoever
    distribute freely and free of charge citing this:
      http://wp.libpf.com/?p=670
 */

#ifndef XLSX_TIMING_H
#define XLSX_TIMING_H

// SYSTEM INCLUDES
#include <ctime>
#include <string>
#include <sstream> // for ostringstream

// PROJECT INCLUDES

// LOCAL INCLUDES

// FORWARD REFERENCES

class Timing {
private:
  mutable std::time_t mytime_t;
  struct std::tm *mytm;
public:
  // http://www.w3.org/TR/NOTE-datetime
  // Complete date plus hours, minutes and seconds:
  //   YYYY-MM-DDThh:mm:ssTZD (eg 1997-07-16T19:20:30+01:00)
  // where:
  //   YYYY = four-digit year
  //   MM   = two-digit month (01=January, etc.)
  //   DD   = two-digit day of month (01 through 31)
  //   hh   = two digits of hour (00 through 23) (am/pm NOT allowed)
  //   mm   = two digits of minute (00 through 59)
  //   ss   = two digits of second (00 through 59)
  //   s    = one or more digits representing a decimal fraction of a second
  //   TZD  = time zone designator (the special UTC (Coordinated Universal Time) designator Z or +hh:mm or -hh:mm)  
  std::string W3CDTF(void);
}; // class Timing

#endif // XLSX_TIMING_H
