/** @file XlsxTest.cc
    @brief Contains the tests for the Xlsx class

    This file is part of XLSX
    Output Office Open XML (OpenXML) spreadsheet files from native C++
    @author (C) Copyright 2013 Paolo Greppi libpf.com
    @date: 20130118
    @version: 0.1

    no warranties whatsoever
    distribute freely and free of charge citing this:
      http://wp.libpf.com/?p=670
 */

// SYSTEM INCLUDES

// PROJECT INCLUDES
#include "Xlsx.h"

// LOCAL INCLUDES

// FORWARD REFERENCES

int main() {
  Xlsx xlsx("test.xlsx");
  xlsx.setAppVersion("00.0001");
  xlsx.setAppName("Test producer");
  
  xlsx.addWorksheet("sparse");
  xlsx.addWorksheet("splitHV");
  xlsx.addWorksheet("splitH");
  xlsx.addWorksheet("splitV");

  xlsx.sheet(0).set(20, 10, std::string("(20,10)"), 1);
  
  xlsx.sheet(1).set(0, 0, std::string("(0,0)"), 1);
  xlsx.sheet(1).set(0, 1, std::string("(0,1)"), 1);
  xlsx.sheet(1).set(0, 2, std::string("(0,2)"), 1);
  xlsx.sheet(1).set(0, 3, std::string("(0,3)"), 1);
  xlsx.sheet(1).set(0, 4, std::string("(0,4)"), 1);
  xlsx.sheet(1).set(1, 0, std::string("(1,0)"), 1);
  xlsx.sheet(1).set(1, 1, std::string("(1,1)"), 1);
  xlsx.sheet(1).set(1, 2, std::string("(1,2)"), 1);
  xlsx.sheet(1).set(1, 3, std::string("(1,3)"), 1);
  xlsx.sheet(1).set(1, 4, std::string("(1,4)"), 1);
  xlsx.sheet(1).set(2, 0, std::string("(2,0)"), 1);
  xlsx.sheet(1).set(2, 1, std::string("(2,1)"), 1);
  xlsx.sheet(1).set(2, 2, std::string("(2,2)"), 1);
  xlsx.sheet(1).set(2, 3, std::string("(2,3)"), 1);
  xlsx.sheet(1).set(2, 4, std::string("(2,4)"), 1);
  xlsx.sheet(1).setColumnWidth(5);
  xlsx.sheet(1).setSplit(1, 1);

  xlsx.sheet(2).set(0, 0, std::string("(0,0)"), 1);
  xlsx.sheet(2).set(0, 1, std::string("(0,1)"), 1);
  xlsx.sheet(2).set(0, 2, std::string("(0,2)"), 1);
  xlsx.sheet(2).set(0, 3, std::string("(0,3)"), 1);
  xlsx.sheet(2).set(0, 4, std::string("(0,4)"), 1);
  xlsx.sheet(2).set(1, 0, std::string("(1,0)"), 1);
  xlsx.sheet(2).set(1, 1, std::string("(1,1)"), 1);
  xlsx.sheet(2).set(1, 2, std::string("(1,2)"), 1);
  xlsx.sheet(2).set(1, 3, std::string("(1,3)"), 1);
  xlsx.sheet(2).set(1, 4, std::string("(1,4)"), 1);
  xlsx.sheet(2).set(2, 0, std::string("(2,0)"), 1);
  xlsx.sheet(2).set(2, 1, std::string("(2,1)"), 1);
  xlsx.sheet(2).set(2, 2, std::string("(2,2)"), 1);
  xlsx.sheet(2).set(2, 3, std::string("(2,3)"), 1);
  xlsx.sheet(2).set(2, 4, std::string("(2,4)"), 1);
  xlsx.sheet(2).setColumnWidth(5);
  xlsx.sheet(2).setColumnWidth(0, 20);
  xlsx.sheet(2).setColumnWidth(1, 10);
  xlsx.sheet(2).setSplit(1, -1);

  /// Supported formats:
  ///   1: bold
  ///   2: bold "yyyy/mm/dd"
  ///   3: plain
  ///   4: "0.00"
  xlsx.sheet(3).set(0, 0, 0.00001, 1);
  xlsx.sheet(3).set(0, 1, 0.00001, 3);
  xlsx.sheet(3).set(0, 2, 0.00001, 4);
  xlsx.sheet(3).set(0, 3, 45000, 1);
  xlsx.sheet(3).set(0, 4, 45000, 2);
  xlsx.sheet(3).set(1, 0, 45000, 3);
  xlsx.sheet(3).set(1, 1, std::string("(1,1)"), 1);
  xlsx.sheet(3).set(1, 2, std::string("àèé€"), 3);
  xlsx.sheet(3).set(1, 3, std::string("0123456789"), 3);
  xlsx.sheet(3).set(1, 4, std::string("01234567890123456789"), 3);
  xlsx.sheet(3).set(2, 0, std::string("012345678901234567890123456789"), 3);
  xlsx.sheet(3).set(2, 1, std::string("0123456789012345678901234567890123456789"), 3);
  xlsx.sheet(3).set(2, 2, std::string("01234567890123456789012345678901234567890123456789"), 3);
  xlsx.sheet(3).set(2, 3, std::string("012345678901234567890123456789012345678901234567890123456789"), 3);
  xlsx.sheet(3).set(2, 4, std::string("0123456789012345678901234567890123456789012345678901234567890123456789"), 3);
  xlsx.sheet(3).setColumnWidth(20);
  xlsx.sheet(3).setSplit(-1, 1);

  return 0;
} // main
